@@ -32,7 +32,7 @@ class NuGen:
 
     def configure_neutrino(self,opts):
         self.nu_pdg = opts.neutrinoPrimary_pdgid
-        self.cs_p = cs.Cross_section(opts.pdf_model,14,2212)
+        self.cs_p = cs.Cross_section(self.pdf_model,14,2212)
         self.cs_n = cs.Cross_section(self.pdf_model,14,2112)
         self.cross_ground_p_NC = cg.cross_ground(self.pdf_model,'nc',self.nu_pdg,2212)
         self.cross_ground_n_NC = cg.cross_ground(self.pdf_model,'nc',self.nu_pdg,2112)
@@ -44,8 +44,11 @@ class NuGen:
 
         if self.nu_energy_mode != 'random':
             self.nu_energy_GeV = opts.neutrinoPrimary_energy_GeV
+        else: self.nu_energy_GeV = opts.neutrinoPrimary_energy_GeV
+
         if self.nu_direction_mode != 'random':
             self.nu_direction = opts.neutrinoPrimary_direction
+        else: self.nu_direction = opts.neutrinoPrimary_direction
 
     def configure_target(self,opts):#FIXME
         self.pdf_model = opts.neutrinoPrimary_pdf_model
